/*
* file CcLabelType.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcLabelType
*
* (C) Copyright IBM Corporation 2004, 2008.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/

package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.Feedback;
import javax.wvcm.WvcmException;

import com.ibm.rational.wvcm.stp.cc.CcTypeBase.TypeCreateFlag;

/**
 * <p>A proxy for a ClearCase label type.
 * </p>
 * <p>A label is a user-defined name that can be attached to a set of
 * related ClearCase element versions.  In base (non-UCM) ClearCase projects,
 * labels could be used to capture the set of versions in a particular
 * development checkpoint, a product release, etc.
 * </p>
 * <p>For more information about labels and label types, see the ClearCase
 * "Guide to Managing Software Projects" manual, and the cleartool man pages "mklbtype",
 * "mklabel", and "config_spec".
 * </p>
 */
public interface CcLabelType extends CcTypeBase
{
    /**
     * <p>Create a new label type at the location identified by this proxy. The
     * location should be an object name selector specifying the label type's name
     * and the repository (VOB) in which to create it.
     * </p>
     * <p>Set the {@link CcTypeBase#SCOPE} property to specify the new type's global scope.
     * If no scope is set, a scope of NONE (ordinary scope) is used.
     * </p>
     * <p>Set the {@link CcTypeBase#INSTANCE_CONSTRAINT} property to determine where the new type
     * may be applied.  Valid values for label types are BRANCH and ELEMENT.  If no constraint
     * is set the default is ELEMENT.
     * </p>
     * <p>Set the {@link CcTypeBase#HAS_SHARED_MASTERSHIP} property to <b>true</b> to allow
     * instances of this type to be created in any VOB replica.  If unspecified, the default
     * mastership is unshared.
     * </p>
     * @param flags Resource-specific creation flags.
     */
    public CcLabelType doCreateCcLabelType(TypeCreateFlag[] flags, Feedback feedback) throws WvcmException;
}
